@@ -15,12 +15,9 @@ implementations.
 
 #### ✨ [Transformers](transformers/index.html)
 
-[Transformers module](transformers/index.html)
-contains implementations for
-[multi-headed attention](transformers/mha.html)
-and
-[relative multi-headed attention](transformers/relative_mha.html).
-
+* [Multi-headed attention](transformers/mha.html)
+* [Transformer building blocks](transformers/models.html)
+* [Relative multi-headed attention](transformers/xl/relative_mha.html).
 * [GPT Architecture](transformers/gpt/index.html)
 * [GLU Variants](transformers/glu_variants/simple.html)
 * [kNN-LM: Generalization through Memorization](transformers/knn/index.html)
@@ -58,6 +55,10 @@ and
 * [Rectified Adam Optimizer](optimizers/radam.html)
 * [AdaBelief Optimizer](optimizers/ada_belief.html)
 
+#### ✨ [Normalization Layers](https://nn.labml.ai/normalization/index.html)
+* [Batch Normalization](https://nn.labml.ai/normalization/batch_norm/index.html)
+* [Layer Normalization](https://nn.labml.ai/normalization/layer_norm/index.html)
+
 ### Installation
 
 ```bash
