@@ -14,7 +14,7 @@ from paper [Attention Is All You Need](https://arxiv.org/abs/1706.03762),
 and derivatives and enhancements of it.
 
 * [Multi-head attention](mha.html)
-* [Relative multi-head attention](relative_mha.html)
+* [Relative multi-head attention](xl/relative_mha.html)
 * [Transformer Encoder and Decoder Models](models.html)
 * [Fixed positional encoding](positional_encoding.html)
 
@@ -49,4 +49,4 @@ It does single GPU training but we implement the concept of switching as describ
 from .configs import TransformerConfigs
 from .models import TransformerLayer, Encoder, Decoder, Generator, EncoderDecoder
 from .mha import MultiHeadAttention
-from .relative_mha import RelativeMultiHeadAttention
+from labml_nn.transformers.xl.relative_mha import RelativeMultiHeadAttention
