@@ -7,15 +7,15 @@ summary: >
 
 # Feedback Transformer
 
-This is an implementation of the paper
+This is a [PyTorch](https://pytorch.org) implementation of the paper
 [Accessing Higher-level Representations in Sequential Transformers with Feedback Memory](https://arxiv.org/abs/2002.09402).
 
-Normal transformers process tokens in parallel and each transformer layer pays attention
+Normal transformers process tokens in parallel. Each transformer layer pays attention
 to the outputs of the previous layer.
 Feedback transformer pays attention to the output of all layers in previous steps.
-So this adds recurrence and we need to process token-by-token.
+So this adds recurrence, and we need to process token-by-token.
 This slows down the training significantly (about 5X - 10X depending on the sequence length).
-However when predicting Feedback Transformer is faster because you can predict the next token
+However, when predicting Feedback Transformer is faster because you can predict the next token
 if you cache the memory vectors.
 
 In order to speed up the training the paper discusses starting with a short sequence length and
@@ -28,7 +28,7 @@ This reduces the memory used for caching during prediction.
 The first half of this file implements this.
 
 The updated feedback transformer shares weights $W^l_k$ and $W^l_v$ used
-to calculate keys and values for among the layers.
+to calculate keys and values among the layers.
 We then calculate the keys and values for each step only once and keep
 them cached.
 The [second half](#shared_kv) of this file implements this.
@@ -155,7 +155,7 @@ class FeedbackAttention(Module):
         # $A_j$
         return ac + bd
 
-    def __call__(self, *,
+    def forward(self, *,
                  query: torch.Tensor,
                  key: torch.Tensor,
                  value: torch.Tensor):
@@ -226,7 +226,7 @@ class FeedbackTransformerLayer(Module):
         self.norm_self_attn = nn.LayerNorm([d_model])
         self.norm_ff = nn.LayerNorm([d_model])
 
-    def __call__(self, *,
+    def forward(self, *,
                  x: torch.Tensor,
                  key: Optional[torch.Tensor],
                  value: Optional[torch.Tensor]):
@@ -272,7 +272,7 @@ class FeedbackTransformer(Module):
         # Softmax for weights before taking the weighted sum
         self.softmax = nn.Softmax(0)
 
-    def __call__(self, x_seq: torch.Tensor):
+    def forward(self, x_seq: torch.Tensor):
         """
         * `x_seq` is the input with shape `[seq_len, batch_size, d_model]`
         """
@@ -470,7 +470,7 @@ class FeedbackTransformerKV(Module):
         # Memory for stacked values
         self.mem_value = Stack(512)
 
-    def __call__(self, x_seq: torch.Tensor):
+    def forward(self, x_seq: torch.Tensor):
         """
         * `x_seq` is the input with shape `[seq_len, batch_size, d_model]`
         """
