@@ -7,21 +7,21 @@ summary: >
 
 # Switch Transformer
 
-This is a miniature implementation of the paper
+This is a miniature [PyTorch](https://pytorch.org) implementation of the paper
 [Switch Transformers: Scaling to Trillion Parameter Models with Simple and Efficient Sparsity](https://arxiv.org/abs/2101.03961).
 Our implementation only has a few million parameters and doesn't do model parallel distributed training.
-It does single GPU training but we implement the concept of switching as described in the paper.
+It does single GPU training, but we implement the concept of switching as described in the paper.
 
 The Switch Transformer uses different parameters for each token by switching among parameters,
 based on the token. So only a fraction of parameters is chosen for each token, so you
 can have more parameters but less computational cost.
 
-The switching happens at the Position-wise Feedforward network (FFN) of of each transformer block.
+The switching happens at the Position-wise Feedforward network (FFN) of each transformer block.
 Position-wise feedforward network is a two sequentially fully connected layers.
-In switch transformer we have multiple FFNs (multiple experts) and
-we chose which one to use based on a router.
+In switch transformer we have multiple FFNs (multiple experts),
+and we chose which one to use based on a router.
 The outputs a set of probabilities for picking a FFN,
-and we pick the one with highest probability and only evaluates that.
+and we pick the one with the highest probability and only evaluates that.
 So essentially the computational cost is same as having a single FFN.
 In our implementation this doesn't parallelize well when you have many or large FFNs since it's all
 happening on a single GPU.
@@ -80,7 +80,7 @@ class SwitchFeedForward(Module):
         self.switch = nn.Linear(d_model, n_experts)
         self.softmax = nn.Softmax(dim=-1)
 
-    def __call__(self, x: torch.Tensor):
+    def forward(self, x: torch.Tensor):
         """
         * `x` is the input to the switching module with shape `[seq_len, batch_size, d_model]`
         """
@@ -189,7 +189,7 @@ class SwitchTransformerLayer(Module):
         self.norm_self_attn = nn.LayerNorm([d_model])
         self.norm_ff = nn.LayerNorm([d_model])
 
-    def __call__(self, *,
+    def forward(self, *,
                  x: torch.Tensor,
                  mask: torch.Tensor):
         # Normalize the vectors before doing self attention
@@ -221,7 +221,7 @@ class SwitchTransformer(Module):
         # Final normalization layer
         self.norm = nn.LayerNorm([layer.size])
 
-    def __call__(self, x: torch.Tensor, mask: torch.Tensor):
+    def forward(self, x: torch.Tensor, mask: torch.Tensor):
         # Run through each transformer layer
         counts, route_prob, n_dropped = [], [], []
         for layer in self.layers:
